@@ -43,7 +43,7 @@ class ServerD:
         if not login_dict.get("pwd"):
             s_type = "serverLoginSSH"
         s_data = server_base_data.get(s_type).format(**login_dict)
-        print(s_data)
+        print(login_dict.get("user"), login_dict.get("host"), login_dict.get("port"))
         self.serverB(s_type, s_data)
 
     def get(self, server_name, locPath, serPath, root=False):
